@@ -2,16 +2,18 @@ import spacy
 from spacy.language import Language
 from spacy.tokens import Doc
 
-from scispacy.custom_sentence_segmenter import combined_rule_sentence_segmenter # pylint: disable-msg=E0611,E0401
-from scispacy.custom_tokenizer import combined_rule_tokenizer # pylint: disable-msg=E0611,E0401
+from scispacy.custom_sentence_segmenter import pysbd_sentencizer
+from scispacy.custom_tokenizer import combined_rule_tokenizer
+
 
 def save_model(nlp: Language, output_path: str):
     nlp.to_disk(output_path)
 
+
 def create_combined_rule_model() -> Language:
-    nlp = spacy.load('en_core_web_sm')
+    nlp = spacy.load("en_core_web_sm")
     nlp.tokenizer = combined_rule_tokenizer(nlp)
-    nlp.add_pipe(combined_rule_sentence_segmenter, first=True)
+    nlp.add_pipe(pysbd_sentencizer, first=True)
     return nlp
 
 
@@ -26,11 +28,12 @@ class WhitespaceTokenizer:
     nlp.tokenizer = WhitespaceTokenizer(nlp.vocab)
     ... use nlp("here is some text") as normal.
     """
+
     def __init__(self, vocab):
         self.vocab = vocab
 
     def __call__(self, text):
-        words = text.split(' ')
+        words = text.split(" ")
         # All tokens 'own' a subsequent space character in
         # this tokenizer. This is a technicality and probably
         # not that interesting.
